Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(463)

Unified Diff: webkit/plugins/ppapi/ppb_file_chooser_impl.h

Issue 10414085: Modified the pepper file chooser API to support filtering files by extensions. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/thunk/resource_creation_api.h ('k') | webkit/plugins/ppapi/ppb_file_chooser_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/plugins/ppapi/ppb_file_chooser_impl.h
diff --git a/webkit/plugins/ppapi/ppb_file_chooser_impl.h b/webkit/plugins/ppapi/ppb_file_chooser_impl.h
index d5afc2d74f2f81487be726721d11fa113e2798e0..478e1c5d897bf7ee638e0a215b1560356a38cde2 100644
--- a/webkit/plugins/ppapi/ppb_file_chooser_impl.h
+++ b/webkit/plugins/ppapi/ppb_file_chooser_impl.h
@@ -36,12 +36,12 @@ class PPB_FileChooser_Impl : public ::ppapi::Resource,
public:
PPB_FileChooser_Impl(PP_Instance instance,
PP_FileChooserMode_Dev mode,
- const char* accept_mime_types);
+ const char* accept_types);
virtual ~PPB_FileChooser_Impl();
static PP_Resource Create(PP_Instance instance,
PP_FileChooserMode_Dev mode,
- const char* accept_mime_types);
+ const char* accept_types);
// Resource overrides.
virtual PPB_FileChooser_Impl* AsPPB_FileChooser_Impl();
@@ -78,15 +78,15 @@ class PPB_FileChooser_Impl : public ::ppapi::Resource,
PP_Var suggested_file_name,
const PP_CompletionCallback& callback) OVERRIDE;
// Splits a comma-separated MIME type list |accept_mime_types|, trims the
// resultant split types, makes them lowercase, and returns them.
// Though this should be private, this is public for testing.
WEBKIT_PLUGINS_EXPORT static std::vector<WebKit::WebString> ParseAcceptValue(
- const std::string& accept_mime_types);
+ const std::string& accept_types);
private:
PP_FileChooserMode_Dev mode_;
- std::string accept_mime_types_;
+ std::string accept_types_;
scoped_refptr< ::ppapi::TrackedCallback> callback_;
// When using the v0.6 of the API, this will contain the output for the
« no previous file with comments | « ppapi/thunk/resource_creation_api.h ('k') | webkit/plugins/ppapi/ppb_file_chooser_impl.cc » ('j') | no next file with comments »
@@ -78,15 +78,15 @@ class PPB_FileChooser_Impl : public ::ppapi::Resource,
PP_Var suggested_file_name,
const PP_CompletionCallback& callback) OVERRIDE;
- // Splits a comma-separated MIME type list |accept_mime_types|, trims the
+ // Splits a comma-separated MIME type/extension list |accept_types|, trims the
// resultant split types, makes them lowercase, and returns them.
// Though this should be private, this is public for testing.

Powered by Google App Engine
This is Rietveld 408576698